
.. image:: https://img.shields.io/badge/badges-awesome-green.svg
   :target: https://github.com/Naereen/badges

.. image:: https://img.shields.io/badge/Made%20with-Python-1f425f.svg
   :target: https://www.python.org/

.. image:: https://img.shields.io/pypi/v/ansicolortags.svg
   :target: https://pypi.python.org/pypi/alicia/

.. image:: https://img.shields.io/pypi/dm/ansicolortags.svg
   :target: https://pypi.python.org/pypi/alicia/

.. image:: https://img.shields.io/pypi/l/ansicolortags.svg
   :target: https://pypi.python.org/pypi/ansicolortags/

.. image:: https://img.shields.io/badge/say-thanks-ff69b4.svg
   :target: https://saythanks.io/to/kennethreitz


================================================
                   AlicIA
================================================

Install and usage
================================================
::

    pip install alicia
    alicia --help


If you just want to see a quick showcase of the tool, download and run `showcase.sh` https://github.com/aemonge/alicia/raw/main/docs/showcase.sh

Features
-----------------------------------------------

To see the full list of features, and option please refer to `alicia --help`

* Download common torchvision datasets
* Select different transforms to train.
* Train, test and predict using different custom-made and torch-vision models.
* Get information about each model.
* Compare models training speed, accuracy, and meta information.
* Tested with MNIST and FashionMNIST.
* View results in the console, or with matplotlib

References
-----------------------------------------------

Useful links found and used while developing this

* https://medium.com/analytics-vidhya/creating-a-custom-dataset-and-dataloader-in-pytorch-76f210a1df5d
* https://stackoverflow.com/questions/51911749/what-is-the-difference-between-torch-tensor-and-torch-tensor
* https://deepai.org/dataset/mnist
* https://medium.com/fenwicks/tutorial-1-mnist-the-hello-world-of-deep-learning-abd252c47709
